==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicInternalFrameTitlePane__24CloseAction.h <==
// public class javax.swing.plaf.basic.BasicInternalFrameTitlePane$CloseAction

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class f02353a2de7b0e85 javax_swing_AbstractAction
// @dep_class e64fd943ade81fb2 javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction

// header file dependencies
// @dep_header javax_swing_AbstractAction

#include "javax/swing/AbstractAction.h"

#ifndef _JC_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction_H_
#define _JC_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction_H_

// Forward structure declarations
struct _jc_java_awt_event_ActionEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction$sub_refs	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction$refs	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction$nonrefs	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction$object	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction$vmethods	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction$vtable	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction$vtype	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction$method$_init$a4e5e3befc8ae789(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction$object *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane$object *);

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction$method$actionPerformed$9046a9754e643ffd(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction$object *, struct _jc_java_awt_event_ActionEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction$method_info$actionPerformed$9046a9754e643ffd;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction$vmethods {
	void	(*actionPerformed$9046a9754e643ffd)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction$object *, struct _jc_java_awt_event_ActionEvent$object *);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_AbstractAction$vmethods	javax_swing_AbstractAction;
	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction$vmethods	javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction$refs {
    _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction$sub_refs	javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction;
    _jc_javax_swing_AbstractAction$sub_refs	javax_swing_AbstractAction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_AbstractAction$sub_nonrefs	javax_swing_AbstractAction;
    _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction$sub_nonrefs	javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction$object {
	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction$vtype _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction_H_ */

==> jc-1.4.5.tar.gz: javax/swing/plaf/basic/BasicInternalFrameTitlePane__24CloseAction.h <==
// public class javax.swing.plaf.basic.BasicInternalFrameTitlePane$CloseAction

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class f02353a2de7b0e85 javax_swing_AbstractAction
// @dep_class e64fd943ade81fb2 javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction

// header file dependencies
// @dep_header javax_swing_AbstractAction

#include "javax/swing/AbstractAction.h"

#ifndef _JC_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction_H_
#define _JC_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction_H_

// Forward structure declarations
struct _jc_java_awt_event_ActionEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction$sub_refs	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction$refs	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction$nonrefs	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction$object	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction$vmethods	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction$vtable	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction$vtype	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction$method$_init$a4e5e3befc8ae789(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction$object *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction$method$actionPerformed$9046a9754e643ffd(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction$object *, struct _jc_java_awt_event_ActionEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction$method_info$actionPerformed$9046a9754e643ffd;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction$vmethods {
	void	(*actionPerformed$9046a9754e643ffd)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction$object *, struct _jc_java_awt_event_ActionEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_AbstractAction$vmethods	javax_swing_AbstractAction;
	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction$vmethods	javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction$refs {
    _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction$sub_refs	javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction;
    _jc_javax_swing_AbstractAction$sub_refs	javax_swing_AbstractAction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_AbstractAction$sub_nonrefs	javax_swing_AbstractAction;
    _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction$sub_nonrefs	javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction$object {
	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction$vtype _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24CloseAction_H_ */
